==> tmaid-2.4.9.tar.gz: tmaid-2.4.9/src/replace.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __REPLACE_H__
#define __REPLACE_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define REPLACE_CANCEL -1
#define REPLACE_OK 1
#define REPLACE_ALL 2
#define REPLACE_NEXT 0


typedef struct _ReplaceString
{
  gboolean arrow;
  gboolean ignorecase;
  gchar *src, *dst;
} ReplaceString;


extern gboolean replace_arrow;              /* ja:検索の設定 */
extern gboolean replace_ignorecase;         /* ja:置換の設定 */
extern gchar *replace_text[32];             /* ja:置換する文字列 */
extern gint replace_num;                    /* ja:登録されている置換文字列 */


/******************************************************************************
*                                                                             *
* ja:置換ダイアログ関数群                                                     *
*                                                                             *
******************************************************************************/
/*  ja:置換ダイアログ表示
     rp,置換情報
    RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
gint
replace_dialog (ReplaceString *rp);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __REPLACE_H__ */

==> tmaid-2.6.2.tar.gz: tmaid-2.6.2/src/replace.h <==
/*
    Text maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __REPLACE_H__
#define __REPLACE_H__


#include "tmaid.h"


G_BEGIN_DECLS


#define REPLACE_CANCEL -1
#define REPLACE_OK 1
#define REPLACE_ALL 2
#define REPLACE_NEXT 0


typedef struct _ReplaceString
{
  gboolean arrow;
  gboolean ignorecase;
  gchar *src, *dst;
} ReplaceString;


extern gboolean replace_arrow;              /* ja:検索の設定 */
extern gboolean replace_ignorecase;         /* ja:置換の設定 */
extern gchar *replace_text[32];             /* ja:置換する文字列 */
extern gint replace_num;                    /* ja:登録されている置換文字列 */


/******************************************************************************
*                                                                             *
* ja:置換ダイアログ関数群                                                     *
*                                                                             *
******************************************************************************/
/*  ja:置換ダイアログ表示
     rp,置換情報
    RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
gint
replace_dialog (ReplaceString *rp);


G_END_DECLS


#endif /* __REPLACE_H__ */
